@@ -18,7 +18,6 @@
 
 #include "kis_colorize_mask.h"
 
-#include <mutex>
 #include <QCoreApplication>
 
 #include <KoColorSpaceRegistry.h>
@@ -164,7 +163,7 @@ struct SetKeyStrokesColorSpaceCommand : public KUndo2Command {
           m_list(list),
           m_node(node) {}
 
-    void undo() {
+    void undo() override {
         KIS_ASSERT_RECOVER_RETURN(m_list->size() == m_oldColors.size());
 
         for (int i = 0; i < m_list->size(); i++) {
@@ -172,7 +171,7 @@ struct SetKeyStrokesColorSpaceCommand : public KUndo2Command {
         }
     }
 
-    void redo() {
+    void redo() override {
         if (m_oldColors.isEmpty()) {
             Q_FOREACH(const KeyStroke &stroke, *m_list) {
                 m_oldColors << stroke.color;
@@ -386,7 +385,7 @@ QRect KisColorizeMask::decorateRect(KisPaintDeviceSP &src,
 
     // Draw the key strokes
     if (m_d->showKeyStrokes) {
-        lockTemporaryTarget();
+        KisIndirectPaintingSupport::ReadLocker locker(this);
 
         KisSelectionSP selection = m_d->cachedSelection.getSelection();
         KisSelectionSP conversionSelection = m_d->cachedConversionSelection.getSelection();
@@ -430,8 +429,6 @@ QRect KisColorizeMask::decorateRect(KisPaintDeviceSP &src,
 
         m_d->cachedSelection.putSelection(selection);
         m_d->cachedSelection.putSelection(conversionSelection);
-
-        unlockTemporaryTarget();
     }
 
     return rect;
@@ -453,12 +450,12 @@ QRect KisColorizeMask::extent() const
             rc |= stroke.dev->extent();
         }
 
-        lockTemporaryTarget();
+        KisIndirectPaintingSupport::ReadLocker locker(this);
+
         KisPaintDeviceSP temporaryTarget = this->temporaryTarget();
         if (temporaryTarget) {
             rc |= temporaryTarget->extent();
         }
-        unlockTemporaryTarget();
     }
 
     return rc;
@@ -477,12 +474,11 @@ QRect KisColorizeMask::exactBounds() const
             rc |= stroke.dev->exactBounds();
         }
 
-        lockTemporaryTarget();
+        KisIndirectPaintingSupport::ReadLocker locker(this);
         KisPaintDeviceSP temporaryTarget = this->temporaryTarget();
         if (temporaryTarget) {
             rc |= temporaryTarget->exactBounds();
         }
-        unlockTemporaryTarget();
     }
 
     return rc;
@@ -521,8 +517,7 @@ void KisColorizeMask::setCurrentColor(const KoColor &_color)
     KoColor color = _color;
     color.convertTo(colorSpace());
 
-    WriteLockableWrapper lock(this);
-    std::lock_guard<WriteLockableWrapper> guard(lock);
+    WriteLocker locker(this);
 
     setNeedsUpdate(true);
 
@@ -558,12 +553,12 @@ struct KeyStrokeAddRemoveCommand : public KisCommandUtils::FlipFlopCommand {
           m_index(index), m_stroke(stroke),
           m_list(list), m_node(node) {}
 
-    void init() {
+    void init() override {
         m_list->insert(m_index, m_stroke);
         emit m_node->sigKeyStrokesListChanged();
     }
 
-    void end() {
+    void end() override {
         KIS_ASSERT_RECOVER_RETURN((*m_list)[m_index] == m_stroke);
         m_list->removeAt(m_index);
         emit m_node->sigKeyStrokesListChanged();
@@ -580,8 +575,7 @@ void KisColorizeMask::mergeToLayer(KisNodeSP layer, KisPostExecutionUndoAdapter
 {
     Q_UNUSED(layer);
 
-    WriteLockableWrapper lock(this);
-    std::lock_guard<WriteLockableWrapper> guard(lock);
+    WriteLocker locker(this);
 
     KisPaintDeviceSP temporaryTarget = this->temporaryTarget();
     const bool isTemporaryTargetErasing = temporaryCompositeOp() == COMPOSITE_ERASE;
@@ -730,14 +724,14 @@ struct SetKeyStrokeColorsCommand : public KUndo2Command {
           m_list(list),
           m_node(node) {}
 
-    void redo() {
+    void redo() override {
         *m_list = m_newList;
 
         emit m_node->sigKeyStrokesListChanged();
         m_node->setDirty();
     }
 
-    void undo() {
+    void undo() override {
         *m_list = m_oldList;
 
         emit m_node->sigKeyStrokesListChanged();
