@@ -352,7 +352,7 @@ bool KisApplication::start(const KisApplicationArguments &args)
     // TODO: fix print & exportAsPdf to work without mainwindow shown
     const bool showmainWindow = !exportAs; // would be !batchRun;
 
-    const bool showSplashScreen = !m_batchRun && qgetenv("NOSPLASH").isEmpty() &&  qgetenv("XDG_CURRENT_DESKTOP") != "GNOME";
+    const bool showSplashScreen = !m_batchRun && qEnvironmentVariableIsEmpty("NOSPLASH") &&  qgetenv("XDG_CURRENT_DESKTOP") != "GNOME";
     if (showSplashScreen) {
         d->splashScreen->show();
         d->splashScreen->repaint();
@@ -387,7 +387,8 @@ bool KisApplication::start(const KisApplicationArguments &args)
         m_mainWindow = KisPart::instance()->createMainWindow();
 
         if (showmainWindow) {
-            QTimer::singleShot(1, m_mainWindow, SLOT(show()));
+            m_mainWindow->initializeGeometry();
+            m_mainWindow->show();
         }
     }
     short int numberOfOpenDocuments = 0; // number of documents open
@@ -397,7 +398,7 @@ bool KisApplication::start(const KisApplicationArguments &args)
         checkAutosaveFiles();
     }
 
-    setSplashScreenLoadingText(""); // done loading, so clear out label
+    setSplashScreenLoadingText(QString()); // done loading, so clear out label
 
     // Get the command line arguments which we have to parse
     int argsCount = args.filenames().count();
@@ -477,6 +478,13 @@ bool KisApplication::start(const KisApplicationArguments &args)
             return nPrinted > 0;
         }
     }
+
+    // fixes BUG:369308  - Krita crashing on splash screen when loading.
+    // trying to open a file before Krita has loaded can cause it to hang and crash
+    d->splashScreen->displayLinks();
+    d->splashScreen->displayRecentFiles();
+
+
     // not calling this before since the program will quit there.
     return true;
 }
