@@ -147,26 +147,26 @@ public:
     {
     }
 
-    ~DocumentProgressProxy() {
+    ~DocumentProgressProxy() override {
         // signal that the job is done
         setValue(-1);
     }
 
-    int maximum() const {
+    int maximum() const override {
         return 100;
     }
 
-    void setValue(int value) {
+    void setValue(int value) override {
         if (m_mainWindow) {
             m_mainWindow->slotProgress(value);
         }
     }
 
-    void setRange(int /*minimum*/, int /*maximum*/) {
+    void setRange(int /*minimum*/, int /*maximum*/) override {
 
     }
 
-    void setFormat(const QString &/*format*/) {
+    void setFormat(const QString &/*format*/) override {
 
     }
 };
@@ -189,7 +189,7 @@ public:
     {
     }
 
-    void setIndex(int idx) {
+    void setIndex(int idx) override {
         KisImageWSP image = this->image();
         image->requestStrokeCancellation();
         if(image->tryBarrierLock()) {
@@ -198,22 +198,35 @@ public:
         }
     }
 
-    void notifySetIndexChangedOneCommand() {
+    void notifySetIndexChangedOneCommand() override {
         KisImageWSP image = this->image();
         image->unlock();
-        image->barrierLock();
+
+        /**
+         * Some very weird commands may emit blocking signals to
+         * the GUI (e.g. KisGuiContextCommand). Here is the best thing
+         * we can do to avoid the deadlock
+         */
+        while(!image->tryBarrierLock()) {
+            QApplication::processEvents();
+        }
     }
 
-    void undo() {
+    void undo() override {
         KisImageWSP image = this->image();
         image->requestUndoDuringStroke();
+
+        if (image->tryUndoUnfinishedLod0Stroke() == UNDO_OK) {
+            return;
+        }
+
         if(image->tryBarrierLock()) {
             KUndo2Stack::undo();
             image->unlock();
         }
     }
 
-    void redo() {
+    void redo() override {
         KisImageWSP image = this->image();
         if(image->tryBarrierLock()) {
             KUndo2Stack::redo();
@@ -347,6 +360,8 @@ public:
     qint32 macroNestDepth;
 
     KisImageSP image;
+    KisImageSP savingImage;
+
     KisNodeSP preActivatedNode;
     KisShapeController* shapeController;
     KoShapeController* koShapeController;
@@ -424,70 +439,6 @@ public:
     class SafeSavingLocker;
 };
 
-class KisDocument::Private::SafeSavingLocker {
-public:
-    SafeSavingLocker(KisDocument::Private *_d)
-        : d(_d),
-          m_locked(false),
-          m_imageLock(d->image, true),
-          m_savingLock(&d->savingMutex)
-    {
-        const int realAutoSaveInterval = KisConfig().autoSaveInterval();
-        const int emergencyAutoSaveInterval = 10; // sec
-
-        /**
-         * Initial try to lock both objects. Locking the image guards
-         * us from any image composition threads running in the
-         * background, while savingMutex guards us from entering the
-         * saving code twice by autosave and main threads.
-         *
-         * Since we are trying to lock multiple objects, so we should
-         * do it in a safe manner.
-         */
-        m_locked = std::try_lock(m_imageLock, m_savingLock) < 0;
-
-        if (!m_locked) {
-            if (d->isAutosaving) {
-                d->disregardAutosaveFailure = true;
-                if (realAutoSaveInterval) {
-                    d->document->setAutoSave(emergencyAutoSaveInterval);
-                }
-            } else {
-                d->image->requestStrokeEnd();
-                QApplication::processEvents();
-
-                // one more try...
-                m_locked = std::try_lock(m_imageLock, m_savingLock) < 0;
-            }
-        }
-
-        if (m_locked) {
-            d->disregardAutosaveFailure = false;
-        }
-    }
-
-    ~SafeSavingLocker() {
-         if (m_locked) {
-             m_imageLock.unlock();
-             m_savingLock.unlock();
-
-             const int realAutoSaveInterval = KisConfig().autoSaveInterval();
-             d->document->setAutoSave(realAutoSaveInterval);
-         }
-     }
-
-    bool successfullyLocked() const {
-        return m_locked;
-    }
-
-private:
-    KisDocument::Private *d;
-    bool m_locked;
-
-    KisImageBarrierLockAdapter m_imageLock;
-    StdLockableWrapper<QMutex> m_savingLock;
-};
-
 KisDocument::KisDocument()
     : d(new Private(this))
 {
@@ -515,7 +466,6 @@ KisDocument::KisDocument()
     d->firstMod = QDateTime::currentDateTime();
     d->lastMod = QDateTime::currentDateTime();
 
-
     // preload the krita resources
     KisResourceServerProvider::instance();
 
@@ -685,12 +635,10 @@ bool KisDocument::saveFile(KisPropertiesConfigurationSP exportConfiguration)
     Q_ASSERT(!tempororaryFileName.isEmpty());
 
     if (!isNativeFormat(outputMimeType)) {
-        Private::SafeSavingLocker locker(d);
-        if (locker.successfullyLocked()) {
-            status = d->importExportManager->exportDocument(tempororaryFileName, outputMimeType, exportConfiguration);
-        } else {
-            status = KisImportExportFilter::UsageError;
-        }
+
+        d->savingImage = d->image->clone(true);
+        status = d->importExportManager->exportDocument(tempororaryFileName, outputMimeType, exportConfiguration);
+        d->savingImage.clear();
 
         ret = status == KisImportExportFilter::OK;
         suppressErrorDialog = (status == KisImportExportFilter::UserCancelled || status == KisImportExportFilter::BadConversionGraph);
@@ -869,7 +817,7 @@ bool KisDocument::isAutoErrorHandlingEnabled() const
 
 void KisDocument::slotAutoSave()
 {
-    if (d->modified && d->modifiedAfterAutosave && !d->isLoading) {
+    if (!d->isAutosaving && d->modified && d->modifiedAfterAutosave && !d->isLoading) {
         // Give a warning when trying to autosave an encrypted file when no password is known (should not happen)
         if (d->specialOutputFlag == SaveEncrypted && d->password.isNull()) {
             // That advice should also fix this error from occurring again
@@ -926,9 +874,7 @@ bool KisDocument::isModified() const
 
 bool KisDocument::saveNativeFormat(const QString & file)
 {
-    Private::SafeSavingLocker locker(d);
-    if (!locker.successfullyLocked()) return false;
-
+    d->savingImage = d->image->clone(true);
     d->lastErrorMessage.clear();
     //dbgUI <<"Saving to store";
 
@@ -943,9 +889,12 @@ bool KisDocument::saveNativeFormat(const QString & file)
         if (f.open(QIODevice::WriteOnly | QIODevice::Text)) {
             bool success = saveToStream(&f);
             f.close();
+            d->savingImage = 0;
             return success;
-        } else
+        } else {
+            d->savingImage = 0;
             return false;
+        }
     }
 
     dbgUI << "KisDocument::saveNativeFormat nativeFormatMimeType=" << nativeFormatMimeType();
@@ -958,6 +907,7 @@ bool KisDocument::saveNativeFormat(const QString & file)
     }
     if (store->bad()) {
         d->lastErrorMessage = i18n("Could not create the file for saving");   // more details needed?
+        d->savingImage = 0;
         delete store;
         return false;
     }
@@ -970,6 +920,7 @@ bool KisDocument::saveNativeFormat(const QString & file)
     } else {
         result = saveNativeFormatCalligra(store);
     }
+    d->savingImage = 0;
     return result;
 }
 
@@ -1070,12 +1021,22 @@ bool KisDocument::saveToStore(KoStore *_store, const QString & _path)
 bool KisDocument::savePreview(KoStore *store)
 {
     QPixmap pix = generatePreview(QSize(256, 256));
-    const QImage preview(pix.toImage().convertToFormat(QImage::Format_ARGB32, Qt::ColorOnly));
+    QImage preview(pix.toImage().convertToFormat(QImage::Format_ARGB32, Qt::ColorOnly));
+    if (preview.size() == QSize(0,0)) {
+        QSize newSize = d->image->bounds().size();
+        newSize.scale(QSize(256, 256), Qt::KeepAspectRatio);
+        preview = QImage(newSize, QImage::Format_ARGB32);
+        preview.fill(QColor(0, 0, 0, 0));
+    }
     KoStoreDevice io(store);
-    if (!io.open(QIODevice::WriteOnly))
+    if (!io.open(QIODevice::WriteOnly)) {
         return false;
-    if (! preview.save(&io, "PNG"))     // ### TODO What is -9 in quality terms?
+    }
+
+    if (!preview.save(&io, "PNG")) {     // ### TODO What is -9 in quality terms?
         return false;
+    }
+
     io.close();
     return true;
 }
@@ -1761,8 +1722,9 @@ bool KisDocument::completeLoading(KoStore* store)
 
 bool KisDocument::completeSaving(KoStore* store)
 {
+    Q_ASSERT(!d->savingImage.isNull());
     d->kraSaver->saveKeyframes(store, url().url(), isStoredExtern());
-    d->kraSaver->saveBinaryData(store, d->image, url().url(), isStoredExtern(), d->isAutosaving);
+    d->kraSaver->saveBinaryData(store, d->savingImage, url().url(), isStoredExtern(), d->isAutosaving);
     bool retval = true;
     if (!d->kraSaver->errorMessages().isEmpty()) {
         setErrorMessage(d->kraSaver->errorMessages().join(".\n"));
@@ -1876,7 +1838,9 @@ QDomDocument KisDocument::saveXML()
     if (d->kraSaver) delete d->kraSaver;
     d->kraSaver = new KisKraSaver(this);
 
-    root.appendChild(d->kraSaver->saveXML(doc, d->image));
+    Q_ASSERT(!d->savingImage.isNull());
+
+    root.appendChild(d->kraSaver->saveXML(doc, d->savingImage));
     if (!d->kraSaver->errorMessages().isEmpty()) {
         setErrorMessage(d->kraSaver->errorMessages().join(".\n"));
     }
@@ -2455,6 +2419,11 @@ KisImageWSP KisDocument::image() const
     return d->image;
 }
 
+KisImageSP KisDocument::savingImage() const
+{
+    return d->savingImage;
+}
+
 
 void KisDocument::setCurrentImage(KisImageSP image)
 {
