@@ -744,8 +744,18 @@ public:
      */
     KisImageWSP newImage(const QString& name, qint32 width, qint32 height, const KoColorSpace * colorspace);
 
+
     KisImageWSP image() const;
 
+    /**
+     * @brief savingImage provides a detached, shallow copy of the original image that must be used when saving.
+     * Any strokes in progress will not be applied to this image, so the result might be missing some data. On
+     * the other hand, it won't block.
+     *
+     * @return a shallow copy of the original image, or 0 is saving is not in progress
+     */
+    KisImageSP savingImage() const;
+
     /**
      * Makes an otherwise empty document ready for import/export
      */
