@@ -98,7 +98,6 @@
 #include <KisMimeDatabase.h>
 #include <brushengine/kis_paintop_settings.h>
 #include "dialogs/kis_about_application.h"
-#include "dialogs/kis_delayed_save_dialog.h"
 #include "dialogs/kis_dlg_preferences.h"
 #include "kis_action.h"
 #include "kis_action_manager.h"
@@ -146,17 +145,17 @@ class ToolDockerFactory : public KoDockFactoryBase
 public:
     ToolDockerFactory() : KoDockFactoryBase() { }
 
-    QString id() const {
+    QString id() const override {
         return "sharedtooldocker";
     }
 
-    QDockWidget* createDockWidget() {
+    QDockWidget* createDockWidget() override {
         KoToolDocker* dockWidget = new KoToolDocker();
         dockWidget->setTabEnabled(false);
         return dockWidget;
     }
 
-    DockPosition defaultDockPosition() const {
+    DockPosition defaultDockPosition() const override {
         return DockRight;
     }
 };
@@ -172,6 +171,7 @@ public:
         , mdiArea(new QMdiArea(parent))
         , windowMapper(new QSignalMapper(parent))
         , documentMapper(new QSignalMapper(parent))
+        , lastExportSpecialOutputFlag(0)
     {
     }
 
@@ -248,7 +248,6 @@ public:
     QByteArray lastExportedFormat;
     int lastExportSpecialOutputFlag  {0};
     QScopedPointer<KisSignalCompressorWithParam<int> > tabSwitchCompressor;
-    bool geometryInitialized  {false};
     QMutex savingEntryMutex;
 
     KisActionManager * actionManager() {
@@ -882,11 +881,8 @@ bool KisMainWindow::saveDocument(KisDocument *document, bool saveas, bool silent
     std::unique_lock<StdLockableWrapper<QMutex>> l(wrapper, std::try_to_lock);
     if (!l.owns_lock()) return false;
 
-    KisDelayedSaveDialog dlg(document->image(), this);
-    dlg.blockIfImageIsBusy();
-
-    if (dlg.result() != QDialog::Accepted) {
-        return false;
+    if (!document->image()->isIdle()) {
+        QMessageBox::warning(this, i18nc("@title:window", "Krita"), i18n("Krita is still rendering the last strokes. Those strokes will not be saved."));
     }
 
     bool reset_url;
@@ -1139,26 +1135,6 @@ void KisMainWindow::redo()
     }
 }
 
-void KisMainWindow::showEvent(QShowEvent *e)
-{
-    KXmlGuiWindow::showEvent(e);
-
-    if (!d->geometryInitialized) {
-        /**
-         * We should move the window only *after* it has been shown on
-         * screen, otherwise it will become owned by a wrong screen, which
-         * will make positioning of all the child widgets wrong.
-         * (see bug https://bugs.kde.org/show_bug.cgi?id=362025)
-         *
-         * This is actually a bug/feature of Qt 5.5.x and it has been
-         * fixed in Qt 5.6.0. So we can avoid this delay on newer versions
-         * of Qt.
-         */
-        QTimer::singleShot(1, this, SLOT(initializeGeometry()));
-        d->geometryInitialized = true;
-    }
-}
-
 void KisMainWindow::closeEvent(QCloseEvent *e)
 {
     d->mdiArea->closeAllSubWindows();
@@ -1329,11 +1305,9 @@ void KisMainWindow::switchTab(int index)
 
 void KisMainWindow::slotFileNew()
 {
-    KisOpenPane *startupWidget = 0;
-
     const QStringList mimeFilter = KisImportExportManager::mimeFilter(KisImportExportManager::Import);
 
-    startupWidget = new KisOpenPane(this, mimeFilter, QStringLiteral("templates/"));
+    KisOpenPane *startupWidget = new KisOpenPane(this, mimeFilter, QStringLiteral("templates/"));
     startupWidget->setWindowModality(Qt::WindowModal);
 
     KisConfig cfg;
