@@ -93,13 +93,15 @@ struct KisToolFreehandHelper::Private
 
 KisToolFreehandHelper::KisToolFreehandHelper(KisPaintingInformationBuilder *infoBuilder,
                                              const KUndo2MagicString &transactionText,
-                                             KisRecordingAdapter *recordingAdapter)
+                                             KisRecordingAdapter *recordingAdapter,
+                                             KisSmoothingOptions *smoothingOptions)
     : m_d(new Private())
 {
     m_d->infoBuilder = infoBuilder;
     m_d->recordingAdapter = recordingAdapter;
     m_d->transactionText = transactionText;
-    m_d->smoothingOptions = KisSmoothingOptionsSP(new KisSmoothingOptions());
+    m_d->smoothingOptions = KisSmoothingOptionsSP(
+                smoothingOptions ? smoothingOptions : new KisSmoothingOptions());
     m_d->canvasRotation = 0;
 
     m_d->strokeTimeoutTimer.setSingleShot(true);
@@ -189,7 +191,6 @@ void KisToolFreehandHelper::initPaint(KoPointerEvent *event,
                                       KoCanvasResourceManager *resourceManager,
                                       KisImageWSP image, KisNodeSP currentNode,
                                       KisStrokesFacade *strokesFacade,
-                                      KisPostExecutionUndoAdapter *undoAdapter,
                                       KisNodeSP overrideNode,
                                       KisDefaultBoundsBaseSP bounds)
 {
@@ -201,7 +202,6 @@ void KisToolFreehandHelper::initPaint(KoPointerEvent *event,
                   image,
                   currentNode,
                   strokesFacade,
-                  undoAdapter,
                   overrideNode,
                   bounds);
 }
@@ -216,7 +216,6 @@ void KisToolFreehandHelper::initPaintImpl(const KisPaintInformation &previousPai
                                           KisImageWSP image,
                                           KisNodeSP currentNode,
                                           KisStrokesFacade *strokesFacade,
-                                          KisPostExecutionUndoAdapter *undoAdapter,
                                           KisNodeSP overrideNode,
                                           KisDefaultBoundsBaseSP bounds)
 {
@@ -239,7 +238,6 @@ void KisToolFreehandHelper::initPaintImpl(const KisPaintInformation &previousPai
 
     m_d->resources = new KisResourcesSnapshot(image,
                                               currentNode,
-                                              undoAdapter,
                                               resourceManager,
                                               bounds);
 
@@ -610,6 +608,7 @@ void KisToolFreehandHelper::stabilizerStart(KisPaintInformation firstPaintInfo)
     m_d->stabilizerPollTimer.start();
 
     m_d->stabilizedSampler.clear();
+    m_d->stabilizedSampler.addEvent(firstPaintInfo);
 }
 
 KisPaintInformation
