@@ -267,7 +267,7 @@ void TimelineRulerHeader::paintSection1(QPainter *painter, const QRect &rect, in
     const int spanEnd = qMin(count(), logicalIndex + spanWidth);
     QRect spanRect(rect.topLeft(), QSize(width * (spanEnd - logicalIndex), textHeight));
 
-    QStyleOptionViewItemV4 option = viewOptions();
+    QStyleOptionViewItem option = viewOptions();
     const int gridHint = style()->styleHint(QStyle::SH_Table_GridLineColor, &option, this);
     const QColor gridColor = static_cast<QRgb>(gridHint);
     const QPen gridPen = QPen(gridColor);
