@@ -74,6 +74,8 @@ bool hasShapeLayerChild(KisNodeSP node)
 
 KisImportExportFilter::ConversionStatus OraExport::convert(const QByteArray& from, const QByteArray& to, KisPropertiesConfigurationSP configuration)
 {
+    Q_UNUSED(configuration);
+
     dbgFile << "ORA export! From:" << from << ", To:" << to << "";
 
     if (from != "application/x-krita")
@@ -88,7 +90,7 @@ KisImportExportFilter::ConversionStatus OraExport::convert(const QByteArray& fro
 
     if (filename.isEmpty()) return KisImportExportFilter::FileNotFound;
 
-    KisImageWSP image = input->image();
+    KisImageWSP image = input->savingImage();
     Q_CHECK_PTR(image);
 
     KisPaintDeviceSP pd = image->projection();
