@@ -141,9 +141,9 @@ public:
     KisToolMoveFactory()
             : KoToolFactoryBase("KritaTransform/KisToolMove") {
         setToolTip(i18n("Move Tool"));
-        setToolType(TOOL_TYPE_TRANSFORM);
+        setSection(TOOL_TYPE_TRANSFORM);
         setActivationShapeId(KRITA_TOOL_ACTIVATION_ID);
-        setPriority(11);
+        setPriority(3);
         setIconName(koIconNameCStr("krita_tool_move"));
         setShortcut(QKeySequence( Qt::Key_T));
     }
